@@ -6,7 +6,13 @@
 ##                the alarms
 ###########################################################################
 
-from PyQt4 import QtCore, QtGui
+
+import data
+
+if(data.UsePySide == True):
+    from PySide import QtCore, QtGui
+else:    
+    from PyQt4 import QtCore, QtGui
 
 import sys
 import os
@@ -19,7 +25,6 @@ import string
 
 import os, os.path
 
-import data
 import records #record data
 
 #own functions
